==> android-3.0-sources.jar: com/virgilsecurity/sdk/crypto/Recipient.java <==
/*
 * Copyright (c) 2015, Virgil Security, Inc.
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * * Neither the name of virgil nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.virgilsecurity.sdk.crypto;

import java.nio.charset.Charset;

/**
 * This class represents Recipient. This class is immutable.
 *
 * @author Andrii Iakovenko
 */
public class Recipient {
	
    private byte[] id;

    /**
     * Create new instance of Recipient.
     *
     * @param id the recipient ID
     */
    public Recipient(byte[] id) {
        if (id == null) {
            throw new IllegalArgumentException("Recipient ID can't be null");
        }
        this.id = id;
    }

    /**
     * Create new instance of Recipient.
     *
     * @param id the recipient ID
     */
    public Recipient(String id) {
        if (id == null) {
            throw new IllegalArgumentException("Recipient ID can't be null");
        }
        this.id = id.getBytes();
    }

    /**
     * Create new instance of Recipient.
     *
     * @param id the recipient ID
     * @param charset
     */
    public Recipient(String id, Charset charset) {
        if (id == null) {
            throw new IllegalArgumentException("Recipient ID can't be null");
        }
        this.id = id.getBytes(charset);
    }

    /**
     *
     * @return recipient ID value
     */
    public byte[] getId() {
        return id;
    }

}

==> android-3.2.1-sources.jar: com/virgilsecurity/sdk/crypto/Recipient.java <==
/*
 * Copyright (c) 2015, Virgil Security, Inc.
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * * Neither the name of virgil nor the names of its
 *   contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.virgilsecurity.sdk.crypto;

import java.nio.charset.Charset;

/**
 * This class represents Recipient. This class is immutable.
 *
 * @author Andrii Iakovenko
 */
public class Recipient {

	private byte[] id;

	/**
	 * Create new instance of Recipient.
	 *
	 * @param id
	 *            the recipient ID
	 */
	public Recipient(byte[] id) {
		if (id == null) {
			throw new IllegalArgumentException("Recipient ID can't be null");
		}
		this.id = id;
	}

	/**
	 * Create new instance of Recipient.
	 *
	 * @param id
	 *            the recipient ID
	 */
	public Recipient(String id) {
		if (id == null) {
			throw new IllegalArgumentException("Recipient ID can't be null");
		}
		this.id = id.getBytes();
	}

	/**
	 * Create new instance of Recipient.
	 *
	 * @param id
	 *            the recipient ID
	 * @param charset
	 */
	public Recipient(String id, Charset charset) {
		if (id == null) {
			throw new IllegalArgumentException("Recipient ID can't be null");
		}
		this.id = id.getBytes(charset);
	}

	/**
	 *
	 * @return recipient ID value
	 */
	public byte[] getId() {
		return id;
	}

}
